@@ -3,10 +3,12 @@ import shutil
 import subprocess
 from pathlib import Path
 
-from creole.setup_utils import update_rst_readme
 from django.conf import settings
 from django.core import checks
+from django.core.cache import cache
 from django.test import TestCase
+from django_tools.unittest_utils.project_setup import check_editor_config
+from packaging.version import Version
 
 import inventory
 
@@ -29,17 +31,13 @@ def test_version(package_root=None, version=None):
     if version is None:
         version = inventory.__version__
 
-    if 'dev' not in version and 'rc' not in version:
+    ver_obj = Version(inventory.__version__)
+
+    if not ver_obj.is_prerelease:
         version_string = f'v{version}'
 
         assert_file_contains_string(
-            file_path=Path(package_root, 'README.creole'),
-            string=version_string
-        )
-
-        assert_file_contains_string(
-            file_path=Path(package_root, 'README.rst'),
-            string=version_string
+            file_path=Path(package_root, 'README.md'), string=version_string
         )
 
     assert_file_contains_string(
@@ -61,7 +59,7 @@ def test_poetry_check(package_root=None):
 
     output = subprocess.check_output(
         [poerty_bin, 'check'],
-        universal_newlines=True,
+        text=True,
         env=os.environ,
         stderr=subprocess.STDOUT,
         cwd=str(package_root),
@@ -70,17 +68,6 @@ def test_poetry_check(package_root=None):
     assert output == 'All set!\n'
 
 
-def test_update_rst_readme(capsys):
-    rest_readme_path = update_rst_readme(
-        package_root=PACKAGE_ROOT, filename='README.creole'
-    )
-    captured = capsys.readouterr()
-    assert captured.out == 'Generate README.rst from README.creole...nothing changed, ok.\n'
-    assert captured.err == ''
-    assert isinstance(rest_readme_path, Path)
-    assert str(rest_readme_path).endswith('/README.rst')
-
-
 class ProjectSettingsTestCase(TestCase):
     def test_project_path(self):
         project_path = settings.PROJECT_PATH
@@ -102,9 +89,33 @@ class ProjectSettingsTestCase(TestCase):
             include_deployment_checks=True,
             databases=None,
         )
-        if all_issues:
+        all_issue_ids = {issue.id for issue in all_issues}
+        excpeted_issues = {
+            'security.W008',  # settings.SECURE_SSL_REDIRECT=False
+            'async.E001',  # os.environ['DJANGO_ALLOW_ASYNC_UNSAFE'] exists
+        }
+        if all_issue_ids != excpeted_issues:
             print('=' * 100)
             for issue in all_issues:
                 print(issue)
             print('=' * 100)
             raise AssertionError('There are check issues!')
+
+    def test_cache(self):
+        # django cache should work in tests, because some tests "depends" on it
+        cache_key = 'a-cache-key'
+        assert cache.get(cache_key) is None
+        cache.set(cache_key, 'the cache content', timeout=1)
+        assert cache.get(cache_key) == 'the cache content'
+        cache.delete(cache_key)
+        assert cache.get(cache_key) is None
+
+    def test_settings(self):
+        assert settings.SETTINGS_MODULE == 'inventory_project.settings.tests'
+        middlewares = [entry.rsplit('.', 1)[-1] for entry in settings.MIDDLEWARE]
+        assert 'AlwaysLoggedInAsSuperUserMiddleware' not in middlewares
+        assert 'DebugToolbarMiddleware' not in middlewares
+
+
+def test_check_editor_config():
+    check_editor_config(package_root=PACKAGE_ROOT)
